==> balloon-0.03-alfa.tar.gz: balloon-0.03-alfa/balloon/amazon/apps/upload_options.py <==


#--------------------------------------------------------------------------------------
## Copyright 2010 Alexey Petrov
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##     http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
##
## See http://sourceforge.net/apps/mediawiki/balloon-foam
##
## Author : Alexey Petrov
##


#--------------------------------------------------------------------------------------
"""
Contains the package dedicated preferences
"""


#------------------------------------------------------------------------------------------
def dump( the_identation_level, the_output ) :
    from balloon.preferences import OptionGroup
    a_container = OptionGroup( 'amazon.data_transfer.upload' )

    from balloon.preferences import dump_begin, dump_resume, dump_end
    dump_begin( the_identation_level, a_container, the_output )

    import data_upload_options
    dump_resume( the_identation_level, data_upload_options.a_container, the_output )
    
    import upload_start_options
    dump_resume( the_identation_level, upload_start_options.a_container, the_output )

    import data_seeding_options
    dump_resume( the_identation_level, data_seeding_options.a_container, the_output )
    
    dump_end( the_identation_level, a_container, the_output )
    pass


#------------------------------------------------------------------------------------------

==> balloon-0.05-alfa.tar.gz: balloon-0.05-alfa/balloon/amazon/apps/upload_options.py <==


#--------------------------------------------------------------------------------------
## Copyright 2010 Alexey Petrov
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##     http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
##
## See http://sourceforge.net/apps/mediawiki/balloon-foam
##
## Author : Alexey Petrov
##


#--------------------------------------------------------------------------------------
"""
Contains the package dedicated preferences
"""


#------------------------------------------------------------------------------------------
def dump( the_identation_level, the_output ) :
    from balloon.preferences import OptionGroup
    a_container = OptionGroup( 'amazon.apps.data_transfer.upload' )

    from balloon.preferences import dump_begin, dump_resume, dump_end
    dump_begin( the_identation_level, a_container, the_output )

    import data_upload_options
    dump_resume( the_identation_level, data_upload_options.a_container, the_output )
    
    import upload_start_options
    dump_resume( the_identation_level, upload_start_options.a_container, the_output )

    import data_seeding_options
    dump_resume( the_identation_level, data_seeding_options.a_container, the_output )
    
    dump_end( the_identation_level, a_container, the_output )
    pass


#------------------------------------------------------------------------------------------
